diff code_part1/OSTC_code_asm_part1/start.asm @ 97:dc349e4264bb

Cleanup CF for bad 15bits value display Cleanup old printf prototype New strings macro
author JeanDo
date Sun, 12 Dec 2010 01:13:48 +0100
parents 3e351e25f5d1
children 6f8e3a08011e
line wrap: on
line diff
--- a/code_part1/OSTC_code_asm_part1/start.asm	Sat Dec 11 19:13:26 2010 +0100
+++ b/code_part1/OSTC_code_asm_part1/start.asm	Sun Dec 12 01:13:48 2010 +0100
@@ -40,9 +40,9 @@
 	call	disable_rs232			; disable UART module
 	call	RTCinit					; reset RTC
 
 ; Extra power-up testing jDG jDG jDG jDG
 	ifdef	TESTING
-		call 	test_menus
+		call 	do_menu_reset_all2
 	endif
 ; DONE jDG jDG jDG jDG
@@ -40,9 +40,9 @@
 	call	RTCinit					; reset RTC
 
-; Extra power-up testing jDG jDG jDG jDG
+; Extra power-up reset jDG jDG jDG jDG
 	ifdef	TESTING